/*
 * Copyright (c) 2008-2026 Jonathan Schleifer <js@nil.im>
 *
 * All rights reserved.
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License version 3.0 only,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * version 3.0 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3.0 along with this program. If not, see
 * <https://www.gnu.org/licenses/>.
 */

#import "NSArray+OFObject.h"
#import "NSData+OFObject.h"
#import "NSDate+OFObject.h"
#import "NSDictionary+OFObject.h"
#import "NSEnumerator+OFObject.h"
#import "NSNumber+OFObject.h"
#import "NSSet+OFObject.h"
#import "NSString+OFObject.h"

#import "OFArray+NSObject.h"
#import "OFData+NSObject.h"
#import "OFDate+NSObject.h"
#import "OFDictionary+NSObject.h"
#import "OFEnumerator+NSObject.h"
#import "OFException+OFSwift.h"
#import "OFNumber+NSObject.h"
#import "OFSet+NSObject.h"
#import "OFString+NSObject.h"
